@@ -1,5 +1,5 @@
 from .version import __version__
-from .request.http import HTTPClient
+from .request.http import HTTPClient, Route
 from .components import Components, RemoveComponents, InlineKeyboard, Keyboard
 from .attachments.audio import Audio
 from .attachments.location import Location
@@ -11,7 +11,7 @@ from .attachments.contact import ContactMessage
 from .chat import Chat, ChatType
 from .message import Message
 from .permissions import AdminPermissions
-from .chatmember import ChatMember, Role
+from .chatmember import ChatMember, MemberRole
 from .callbackquery import CallbackQuery
 from .update import Update
 from .updater import Updater
@@ -40,11 +40,12 @@ __all__ = (
     "Invoice",
     "Price",
     "HTTPClient",
+    "Route",
     "BaleError",
     "APIError",
     "AdminPermissions",
     "ChatMember", 
-    "Role"
+    "MemberRole"
 )
 
 __title__ = "python-bale-bot"
