@@ -25,7 +25,7 @@
 from __future__ import annotations
 from typing import TYPE_CHECKING
 if TYPE_CHECKING:
-    from bale import Bot, Message
+    from bale import Bot, Message, User, Photo
 
 
 __all__ = (
@@ -105,6 +105,18 @@ class Chat:
         """Get chat type"""
         return self._type
 
+    @property
+    def mention(self):
+        """Mention Chat"""
+        return ("@" + self.username) if self.username else None
+
+    @property
+    def link(self):
+        """Get Chat Link"""
+        if self.username:
+            return "https://ble.ir/@{username}".format(username=self.username)
+        return None
+
     async def send(self, text: str, components=None):
         """Send Message in Chat
         
@@ -114,17 +126,48 @@ class Chat:
         Returns:
             :class:`bale.Message`
         """
-        return await self.bot.send_message(self.chat_id, text, components=components)
+        return await self.bot.send_message(self, text, components=components)
 
-    async def get_chat_member(self, user_id: str):
+    async def send_photo(self, photo: bytes | str | "Photo", caption: str = None):
+        """Send Photo in Chat
+
+        Args:
+            photo (:class:`bytes`|:class:`str`|:class:`bale.Photo`): Photo.
+            caption (:class:`str`): Message caption.
+        Raises:
+            :class:`bale.Error`
+        Returns:
+            :class:`bale.Message`: On success, the sent Message is returned.
+        """
+        return await self.bot.send_photo(self, photo, caption)
+
+    async def leave(self):
+        """:meth:`bale.Bot.leave_chat`.
+
+        Returns:
+            :bool:
+        """
+        return await self.bot.leave_chat(self)
+
+    async def add_user(self, user: "User"):
+        """:meth:`bale.Bot.invite_to_chat`.
+
+        Args:
+            user (:class:`bale.User`)
+        Returns:
+            :class:`bale.Message`
+        """
+        return await self.bot.invite_to_chat(self, user)
+
+    async def get_chat_member(self, user: "User"):
         """:meth:`bale.Bot.get_chat_member`.
 
             Args:
-                user_id (str): User ID.
+                user (:class:`bale.User`): User.
             Returns:
                 :class:`bale.ChatMember`
         """
-        return await self.bot.get_chat_member(chat_id=self.chat_id, user_id=user_id)
+        return await self.bot.get_chat_member(self, user)
 
     async def get_chat_members_count(self):
         """:meth:`bale.Bot.get_chat_members_count`.
@@ -132,7 +175,7 @@ class Chat:
             Returns:
                 :int:
         """
-        return await self.bot.get_chat_members_count(chat_id=self.chat_id)
+        return await self.bot.get_chat_members_count(self)
 
     async def get_chat_administrators(self):
         """:meth:`bale.Bot.get_chat_administrators`.
@@ -142,7 +185,7 @@ class Chat:
         Returns:
             List[:class:`bale.ChatMember`]
         """
-        return await self.bot.get_chat_administrators(self.chat_id)
+        return await self.bot.get_chat_administrators(self)
 
     @classmethod
     def from_dict(cls, data: dict, bot):
