@@ -21,34 +21,46 @@
     OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
     SOFTWARE.
 """
-
-from bale.version import BALE_API_BASE_URL
+from bale.version import BALE_API_BASE_URL, BALE_API_FILE_URL
+import asyncio
 import aiohttp
-from ..error import (NetworkError, HTTPException, TimeOut, NotFound, Forbidden, APIError, BaleError)
+from ..error import (NetworkError, HTTPException, TimeOut, NotFound, Forbidden, APIError, BaleError, HTTPClientError)
 
 
-__all__ = ("HTTPClient",)
+__all__ = ("HTTPClient", "Route")
 
 
 class Route:
 	"""Route Class for http"""
 	BASE = BALE_API_BASE_URL
+	BASE_FILE = BALE_API_FILE_URL
 
 	__slots__ = (
 		"method",
 		"path",
-		"url",
-		"token"
+		"token",
+		"_base"
 	)
 
 	def __init__(self, method: str, path: str, token: str):
 		if not isinstance(token, str):
 			raise TypeError("token is not str!\ntoken is a {}".format(token.__class__))
-		self.url = self.BASE + "bot" + token + "/" + path
 		self.method = method
 		self.path = path
 		self.token = token
+		self._base = self.BASE
 
+	@property
+	def url(self):
+		"""Export url"""
+		return self.BASE + "bot" + self.token + "/" + self.path
+
+	def set_base(self, _value):
+		"""Set base url for route"""
+		if not _value in (self.BASE, self.BASE_FILE):
+			raise TypeError("_value incorrect!")
+
+		self._base = _value
 
 class HTTPClient:
 	"""Send a Request to BALE API Server"""
@@ -87,17 +99,24 @@ class HTTPClient:
 				response: aiohttp.ClientResponse = response
 				if response.status == 200:
 					payload = await response.json()
-					if not payload.get("ok"):
-						raise APIError(
+					return response, payload
+				elif response.status == 400:
+					payload = await response.json()
+					if payload.get("description") == HTTPClientError.USER_OR_CHAT_NOT_FOUND:
+						payload = None
+						return response, payload
+					elif payload.get("description") == HTTPClientError.RATE_LIMIT:
+						await asyncio.sleep(1)
+						return await self.request(route, **kwargs)
+					raise APIError(
 							str(payload.get("error_code")) + payload.get("description")
 						)
-					return response, payload
 				elif response.status == 404:
 					raise NotFound()
 				elif response.status == 403:
 					raise Forbidden()
-				else:
-					raise HTTPException(response, response.json())
+				json = await response.json()
+				raise HTTPException(response, json)
 		except aiohttp.client_exceptions.ClientConnectorError as error:
 			raise NetworkError(str(error))
 		except aiohttp.client_exceptions.ServerTimeoutError:
@@ -105,6 +124,19 @@ class HTTPClient:
 		except aiohttp.client_exceptions.ClientOSError as error:
 			raise BaleError(error)
 
+	async def get_file(self, file_id):
+		async with self.__session.get(BALE_API_FILE_URL + "/" + "bot" + self.token + "/" + file_id) as response:
+			if response.status == 200:
+				return await response.read()
+			elif response.status == 400:
+				raise NotFound()
+			elif response.status == 403:
+				raise Forbidden()
+			else:
+				raise APIError("failed to read file")
+
+		raise RuntimeError("failed to read file")
+
 	def send_message(self, chat_id, text, *, components=None, reply_to_message_id=None):
 		payload = {
 			"chat_id": chat_id,
@@ -117,6 +149,18 @@ class HTTPClient:
 
 		return self.request(Route("POST", "sendMessage", self.token), json=payload)
 
+	def send_photo(self, chat_id, photo, caption=None, reply_to_message_id=None):
+		payload = {
+			"chat_id": chat_id,
+			"photo": photo
+		}
+		if caption:
+			payload["caption"] = caption
+		if reply_to_message_id:
+			payload["reply_to_message_id"] = reply_to_message_id
+
+		return self.request(Route("POST", "SendPhoto", self.token), data=payload)
+
 	def send_invoice(self, chat_id, title, description, provider_token, prices, photo_url=None, need_name=False, need_phone_number=False, need_email=False, need_shipping_address=False, is_flexible=True):
 		payload = {"chat_id": chat_id, "title": title, "description": description, "provider_token": provider_token, "prices": prices}
 		if photo_url:
@@ -153,7 +197,7 @@ class HTTPClient:
 			payload["offset"] = offset
 		if limit:
 			payload["limit"] = limit
-		return self.request(Route("POST", "getupdates", self.token), data=payload)
+		return self.request(Route("POST", "getupdates", self.token), json=payload)
 
 	def delete_webhook(self):
 		return self.request(Route("GET", "deleteWebhook", self.token))
@@ -164,6 +208,9 @@ class HTTPClient:
 	def get_chat(self, chat_id):
 		return self.request(Route("GET", "getchat", self.token), params=dict(chat_id=chat_id))
 
+	def leave_chat(self, chat_id):
+		return self.request(Route("GET", "leaveChat", self.token), params=dict(chat_id=chat_id))
+
 	def get_chat_administrators(self, chat_id):
 		return self.request(Route("GET", "getChatAdministrators", self.token), params=dict(chat_id=chat_id))
 
@@ -172,3 +219,6 @@ class HTTPClient:
 
 	def get_chat_member(self, chat_id, member_id):
 		return self.request(Route("GET", "getChatMember", self.token), params=dict(chat_id=chat_id, user_id=member_id))
+
+	def invite_to_chat(self, chat_id, user_id):
+		return self.request(Route("GET", "InviteUser", self.token), json=dict(chat_id=chat_id, user_id=user_id))
